<?xml version="1.0" ?><!DOCTYPE TS><TS language="ach" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status invisible</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status busy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose Status</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AutoresponderConfigurator</name>
    <message>
        <source>I am busy.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AutoresponderMessageFilter</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>